@@ -15,7 +15,7 @@
 from __future__ import unicode_literals
 
 import caniusepython3.__main__ as ciu_main
-from caniusepython3.test import mock, unittest
+from caniusepython3.test import mock, unittest, skip_pypi_timeouts
 
 import io
 import logging
@@ -26,7 +26,7 @@ EXAMPLE_REQUIREMENTS = """
 # From
 #  http://www.pip-installer.org/en/latest/reference/pip_install.html#requirement-specifiers
 # but without the quotes for shell protection.
-FooProject >= 1.2
+Foo.Project >= 1.2
 Fizzy [foo, bar]
 PickyThing<1.6,>1.9,!=1.9.6,<2.0a0,==2.4c1
 Hello
@@ -37,7 +37,7 @@ file:../../lib/project
 """
 
 EXAMPLE_EXTRA_REQUIREMENTS = """
-testingstuff
+testing-stuff
 """
 
 EXAMPLE_METADATA = """Metadata-Version: 1.2
@@ -50,7 +50,7 @@ Author-email: tarek@ziade.org
 License: PSF
 Keywords: keyring,password,crypt
 Requires-Dist: foo; sys.platform == 'okook'
-Requires-Dist: bar
+Requires-Dist: bar.baz
 Platform: UNKNOWN
 """
 
@@ -66,10 +66,10 @@ Requires-Dist: baz
 
 class CLITests(unittest.TestCase):
 
-    expected_requirements = frozenset(['FooProject', 'Fizzy', 'PickyThing',
-                                       'Hello'])
-    expected_extra_requirements = frozenset(['testingstuff'])
-    expected_metadata = frozenset(['foo', 'bar'])
+    expected_requirements = frozenset(['foo-project', 'fizzy', 'pickything',
+                                       'hello'])
+    expected_extra_requirements = frozenset(['testing-stuff'])
+    expected_metadata = frozenset(['foo', 'bar-baz'])
     expected_extra_metadata = frozenset(['baz'])
 
     def setUp(self):
@@ -125,9 +125,9 @@ class CLITests(unittest.TestCase):
         self.assertEqual(set(got), self.expected_metadata)
 
     def test_cli_for_projects(self):
-        args = ['--projects', 'foo', 'bar']
+        args = ['--projects', 'foo', 'bar.baz']
         got = ciu_main.projects_from_cli(args)
-        self.assertEqual(set(got), frozenset(['foo', 'bar']))
+        self.assertEqual(set(got), frozenset(['foo', 'bar-baz']))
 
     def test_message_plural(self):
         blockers = [['A'], ['B']]
@@ -149,11 +149,19 @@ class CLITests(unittest.TestCase):
                 'its transition:')
         self.assertEqual(messages[1], want)
 
-    def test_message_no_blockers(self):
+    @mock.patch('sys.stdout', autospec=True)
+    def test_message_no_blockers_flair_on_utf8_terminal(self, mock_stdout):
+        mock_stdout.encoding = 'UTF-8'
         messages = ciu_main.message([])
-        self.assertEqual(
-            ['You have 0 projects blocking you from using Python 3!'],
-            messages)
+        expected = ['\U0001f389  You have 0 projects blocking you from using Python 3!']
+        self.assertEqual(expected, messages)
+
+    @mock.patch('sys.stdout', autospec=True)
+    def test_message_no_blockers(self, mock_stdout):
+        mock_stdout.encoding = None
+        messages = ciu_main.message([])
+        expected = ['You have 0 projects blocking you from using Python 3!']
+        self.assertEqual(expected, messages)
 
     def test_pprint_blockers(self):
         simple = [['A']]
@@ -185,6 +193,7 @@ class CLITests(unittest.TestCase):
 #@unittest.skip('faster testing')
 class NetworkTests(unittest.TestCase):
 
+    @skip_pypi_timeouts
     @mock.patch('sys.stdout', io.StringIO())
     def test_e2e(self):
         # Make sure at least one project that will never be in Python 3 is
